Apply OPF/SCED dispatch solutions back into a Network.
These functions close the gap between the dispatch/OPF solvers and the
power flow / N-1 contingency analysis solvers. After solving OPF or SCED,
call one of these to stamp the optimal dispatch onto the network so that
a subsequent solve_ac_pf, compute_n1, or any other network analysis
operates at the dispatched operating point.
Enums
- Apply
Solution Error - Error returned when applying solver outputs back into a
Network.
Functions
- apply_
bus_ voltages - Stamp bus voltage magnitudes and angles onto the network in current bus order.
- apply_
bus_ voltages_ by_ bus_ number - Stamp bus voltage magnitudes and angles onto the network by external bus number.
- apply_
dispatch_ mw - Apply a generator dispatch vector (MW, one per in-service generator) to the network.
- apply_
opf_ dispatch - Apply an OPF solution’s generator dispatch and (optionally) bus voltages
back into a
Network.